# Generated by roxygen2: do not edit by hand

export(ssim_bandwidth)
export(ssim_polygon)
export(ssim_raster)
importFrom(FNN,get.knn)
importFrom(ggplot2,aes)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_rect)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,geom_vline)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(knitr,kable)
importFrom(scales,rescale)
importFrom(sf,st_centroid)
importFrom(sf,st_coordinates)
importFrom(sf,st_geometry)
importFrom(stats,p.adjust)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,sd)
importFrom(stats,var)
importFrom(terra,compareGeom)
importFrom(terra,crop)
importFrom(terra,focal)
importFrom(terra,global)
importFrom(terra,ifel)
importFrom(terra,mask)
importFrom(terra,nlyr)
importFrom(terra,values)
importFrom(utils,globalVariables)
